==> ddskk_14.0.91.orig.tar.gz: ddskk-14.0.91/skk-version.el <==
;;; skk-version.el --- version information for SKK

;; Copyright (C) 2000, 2001, 2003 NAKAJIMA Mikio <minakaji@namazu.org>

;; Author: NAKAJIMA Mikio <minakaji@namazu.org>
;; Maintainer: SKK Development Team <skk@ring.gr.jp>
;; Version: $Id: skk-version.el,v 1.34 2010/01/27 06:26:42 skk-cvs Exp $
;; Keywords: japanese, mule, input method
;; Last Modified: $Date: 2010/01/27 06:26:42 $

;; This file is part of Daredevil SKK.

;; Daredevil SKK is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or
;; (at your option) any later version.

;; Daredevil SKK is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with Daredevil SKK, see the file COPYING.  If not, write to
;; the Free Software Foundation Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; This is a copy of elmo-version.el and wl-version.el...

;;; Code:

(require 'product)
(provide 'skk-version) ; have to declare in the top.

(product-provide 'skk-version
  (product-define "Daredevil SKK" nil '(14 0 91) "Syounai"))

;; set version-string
(if (fboundp 'product-version-as-string)
    (product-version-as-string 'skk-version)
  (product-string-1 'skk-version))

;;;###autoload
(defun skk-version (&optional without-codename)
  "Return SKK version with its codename.
If WITHOUT-CODENAME is non-nil, simply return SKK version without
the codename."
  (interactive "P")
  (if (interactive-p)
      (message "%s" (skk-version without-codename))
    (product-string-1 'skk-version (not without-codename))))

;; for backward compatibility
;;(defconst skk-version (product-version-string (product-find 'skk-version)))
;;(make-obsolete-variable
;; 'skk-version
;; "use (product-version-string (product-find 'skk-version)) instead.")
;;
;; (defconst skk-codename (product-code-name (product-find 'skk-version)))
;; (make-obsolete-variable
;;  'skk-codename
;;  "use (product-code-name (product-find 'skk-version)) instead.")
;;
;; (defconst skk-major-version (string-to-int (substring skk-version 0 2)))
;; (defconst skk-minor-version (string-to-int (substring skk-version 3)))
;; (defconst skk-branch-name "Daredevil")

;;; skk-version.el ends here

==> ddskk-14.1.tar.gz: ddskk-14.1/skk-version.el <==
;;; skk-version.el --- version information for SKK

;; Copyright (C) 2000, 2001, 2003 NAKAJIMA Mikio <minakaji@namazu.org>

;; Author: NAKAJIMA Mikio <minakaji@namazu.org>
;; Maintainer: SKK Development Team <skk@ring.gr.jp>
;; Version: $Id: skk-version.el,v 1.37 2010/09/05 02:20:46 skk-cvs Exp $
;; Keywords: japanese, mule, input method
;; Last Modified: $Date: 2010/09/05 02:20:46 $

;; This file is part of Daredevil SKK.

;; Daredevil SKK is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or
;; (at your option) any later version.

;; Daredevil SKK is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with Daredevil SKK, see the file COPYING.  If not, write to
;; the Free Software Foundation Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;;; Code:

(put 'skk-version 'product-name "Daredevil SKK")
(put 'skk-version 'version-string "14.1")
(put 'skk-version 'codename "Syounai")

;;;###autoload
(defun skk-version (&optional without-codename)
  "Return SKK version with its codename.
If WITHOUT-CODENAME is non-nil, simply return SKK version without
the codename."
  (interactive "P")
  (if (interactive-p)
      (message "%s" (skk-version without-codename))
    (if without-codename
	(format "%s/%s"
		(get 'skk-version 'product-name)
		(get 'skk-version 'version-string))
      (format "%s/%s (%s)"
	      (get 'skk-version 'product-name)
	      (get 'skk-version 'version-string)
	      (get 'skk-version 'codename)))))

(provide 'skk-version)

;;; skk-version.el ends here
